@@ -94,6 +94,7 @@ DiagramScene::DiagramScene(QMenu *itemMenu, QObject *parent)
     myCursor.setRect(QRectF(-myCursorWidth/2,-myCursorWidth/2,myCursorWidth,myCursorWidth));
     myCursor.setPen(QPen(Qt::gray));
     myCursor.setZValue(10.0);
+    myCursor.setFlag(QGraphicsItem::ItemIgnoresTransformations);
     addItem(&myCursor);
 }
 
@@ -982,6 +983,9 @@ void DiagramScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
                     textItem->setTextInteractionFlags(Qt::TextEditorInteraction);
                     textItem->setSelected(true);
                     textItem->setFocus();
+                    auto *p=qgraphicsitem_cast<DiagramPathItem*>(item);
+                    p->setTextMode();
+                    p->update();
                 }else{
                     // path item, add text in center of line segment
                     textItem = makeTextItem(item);
@@ -1013,6 +1017,9 @@ void DiagramScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
                     if(angle>=280 && angle<=350){
                         textItem->setAlignment(Qt::AlignBottom|Qt::AlignLeft);
                     }
+                    auto *p=qgraphicsitem_cast<DiagramPathItem*>(item);
+                    p->setTextMode();
+                    p->update();
 
                     emit textInserted(textItem);
                 }
